On 06/20/2012 05:28 PM, Michal Hocko wrote:
On Mon 18-06-12 14:27:59, Glauber Costa wrote:
From: Suleiman Souhlal <[email protected]>

Signed-off-by: Suleiman Souhlal <[email protected]>
Signed-off-by: Glauber Costa <[email protected]>
Acked-by: Kamezawa Hiroyuki <[email protected]>

I am not sure the patch is good to merge on its own without the rest.
One comment bellow.

---
  mm/memcontrol.c |   18 +++++++++---------
  1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/mm/memcontrol.c b/mm/memcontrol.c
index ce15be4..00b9f1e 100644
--- a/mm/memcontrol.c
+++ b/mm/memcontrol.c
@@ -1998,19 +1998,19 @@ static DEFINE_PER_CPU(struct memcg_stock_pcp, 
memcg_stock);
  static DEFINE_MUTEX(percpu_charge_mutex);

  /*
  * Try to consume stocked charge on this cpu. If success, one page is consumed
  * from local stock and true is returned. If the stock is 0 or charges from a
  * cgroup which is not current target, returns false. This stock will be
  * refilled.
   */
-static bool consume_stock(struct mem_cgroup *memcg)
+static bool consume_stock(struct mem_cgroup *memcg, int nr_pages)
  {
        struct memcg_stock_pcp *stock;
        bool ret = true;

I guess you want:
        if (nr_pages > CHARGE_BATCH)
                return false;

because you don't want to try to use stock for THP pages.


The code reads:

+       if (memcg == stock->cached && stock->nr_pages >= nr_pages)
+               stock->nr_pages -= nr_pages;
@@ -1998,19 +1998,19 @@ static DEFINE_PER_CPU(struct memcg_stock_pcp, 

  /*
- * Try to consume stocked charge on this cpu. If success, one page is consumed
- * from local stock and true is returned. If the stock is 0 or charges from a
- * cgroup which is not current target, returns false. This stock will be
- * refilled.
+ * Try to consume stocked charge on this cpu. If success, nr_pages pages are
+ * consumed from local stock and true is returned. If the stock is 0 or
+ * charges from a cgroup which is not current target, returns false.
+ * This stock will be refilled.
   */

Isn't stock->nr_pages always <= CHARGE_BATCH by definition?

_______________________________________________
Devel mailing list
[email protected]
https://openvz.org/mailman/listinfo/devel

Reply via email to